==> logs-1.60.0-sources.jar: software/amazon/awscdk/services/logs/SpaceDelimitedTextPattern.java <==
package software.amazon.awscdk.services.logs;

/**
 * Space delimited text pattern.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:06.542Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.SpaceDelimitedTextPattern")
public class SpaceDelimitedTextPattern extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.logs.IFilterPattern {

    protected SpaceDelimitedTextPattern(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SpaceDelimitedTextPattern(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param columns This parameter is required.
     * @param restrictions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected SpaceDelimitedTextPattern(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> columns, final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.util.List<software.amazon.awscdk.services.logs.ColumnRestriction>> restrictions) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(columns, "columns is required"), java.util.Objects.requireNonNull(restrictions, "restrictions is required") });
    }

    /**
     * Construct a new instance of a space delimited text pattern.
     * <p>
     * Since this class must be public, we can't rely on the user only creating it through
     * the <code>LogPattern.spaceDelimited()</code> factory function. We must therefore validate the
     * argument in the constructor. Since we're returning a copy on every mutation, and we
     * don't want to re-validate the same things on every construction, we provide a limited
     * set of mutator functions and only validate the new data every time.
     * <p>
     * @param columns This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern construct(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> columns) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class, "construct", software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class, new Object[] { java.util.Objects.requireNonNull(columns, "columns is required") });
    }

    /**
     * Restrict where the pattern applies.
     * <p>
     * @param columnName This parameter is required.
     * @param comparison This parameter is required.
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern whereNumber(final @org.jetbrains.annotations.NotNull java.lang.String columnName, final @org.jetbrains.annotations.NotNull java.lang.String comparison, final @org.jetbrains.annotations.NotNull java.lang.Number value) {
        return this.jsiiCall("whereNumber", software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class, new Object[] { java.util.Objects.requireNonNull(columnName, "columnName is required"), java.util.Objects.requireNonNull(comparison, "comparison is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * Restrict where the pattern applies.
     * <p>
     * @param columnName This parameter is required.
     * @param comparison This parameter is required.
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern whereString(final @org.jetbrains.annotations.NotNull java.lang.String columnName, final @org.jetbrains.annotations.NotNull java.lang.String comparison, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        return this.jsiiCall("whereString", software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class, new Object[] { java.util.Objects.requireNonNull(columnName, "columnName is required"), java.util.Objects.requireNonNull(comparison, "comparison is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getLogPatternString() {
        return this.jsiiGet("logPatternString", java.lang.String.class);
    }
}

==> logs-1.84.0-sources.jar: software/amazon/awscdk/services/logs/SpaceDelimitedTextPattern.java <==
package software.amazon.awscdk.services.logs;

/**
 * Space delimited text pattern.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.15.0 (build 585166b)", date = "2021-01-12T21:08:09.657Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.SpaceDelimitedTextPattern")
public class SpaceDelimitedTextPattern extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.logs.IFilterPattern {

    protected SpaceDelimitedTextPattern(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SpaceDelimitedTextPattern(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param columns This parameter is required.
     * @param restrictions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected SpaceDelimitedTextPattern(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> columns, final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.util.List<software.amazon.awscdk.services.logs.ColumnRestriction>> restrictions) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(columns, "columns is required"), java.util.Objects.requireNonNull(restrictions, "restrictions is required") });
    }

    /**
     * Construct a new instance of a space delimited text pattern.
     * <p>
     * Since this class must be public, we can't rely on the user only creating it through
     * the <code>LogPattern.spaceDelimited()</code> factory function. We must therefore validate the
     * argument in the constructor. Since we're returning a copy on every mutation, and we
     * don't want to re-validate the same things on every construction, we provide a limited
     * set of mutator functions and only validate the new data every time.
     * <p>
     * @param columns This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern construct(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> columns) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class, "construct", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class), new Object[] { java.util.Objects.requireNonNull(columns, "columns is required") });
    }

    /**
     * Restrict where the pattern applies.
     * <p>
     * @param columnName This parameter is required.
     * @param comparison This parameter is required.
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern whereNumber(final @org.jetbrains.annotations.NotNull java.lang.String columnName, final @org.jetbrains.annotations.NotNull java.lang.String comparison, final @org.jetbrains.annotations.NotNull java.lang.Number value) {
        return software.amazon.jsii.Kernel.call(this, "whereNumber", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class), new Object[] { java.util.Objects.requireNonNull(columnName, "columnName is required"), java.util.Objects.requireNonNull(comparison, "comparison is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * Restrict where the pattern applies.
     * <p>
     * @param columnName This parameter is required.
     * @param comparison This parameter is required.
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern whereString(final @org.jetbrains.annotations.NotNull java.lang.String columnName, final @org.jetbrains.annotations.NotNull java.lang.String comparison, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        return software.amazon.jsii.Kernel.call(this, "whereString", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.SpaceDelimitedTextPattern.class), new Object[] { java.util.Objects.requireNonNull(columnName, "columnName is required"), java.util.Objects.requireNonNull(comparison, "comparison is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getLogPatternString() {
        return software.amazon.jsii.Kernel.get(this, "logPatternString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
